@@ -21,11 +21,11 @@
  *  1998-09-22 - i18n - Arnaldo Carvalho de Melo <acme@conectiva.com.br>
  */
 
-/* 	$Id: sndconfig.c,v 1.162 2002/04/08 02:34:15 notting Exp $	 */
+/* 	$Id: sndconfig.c,v 1.164 2003/01/01 02:59:55 notting Exp $	 */
 
 #ifndef lint
 static char vcid[] =
-    "$Id: sndconfig.c,v 1.162 2002/04/08 02:34:15 notting Exp $";
+    "$Id: sndconfig.c,v 1.164 2003/01/01 02:59:55 notting Exp $";
 #endif				/* lint */
 
 #include <ftw.h>
@@ -58,7 +58,7 @@ static char vcid[] =
 
 /* This one should be defined in the Makefile ... */
 #ifndef VERSION
-#define VERSION "$Revision: 1.162 $"
+#define VERSION "$Revision: 1.164 $"
 #endif
 
 /* Typing all this out is a pain... */
@@ -826,12 +826,12 @@ static void mungeList(int list[10], int value)
     }
 }
 
-static char mod_name[100]; 
+static char mod_name[100], cmod_name[100]; 
 
 static int isModule(const char *filename, const struct stat *sb, int flag) {
 	char *fname = basename(filename);
 	/* ugly hack; ignore things under build symlink */
-	if (!strcmp(fname,mod_name) && !strstr(filename,"/build/")) {
+	if ((!strcmp(fname,mod_name) || !strcmp(fname,cmod_name)) && !strstr(filename,"/build/")) {
 		return 1;
 	}
 	return 0;
@@ -863,10 +863,11 @@ int isAvailable(char *modulename)
 	
 	uname(&utsbuf);
 	snprintf(mod_name,100,"%s.o",modulename);
+	snprintf(cmod_name,100,"%s.o.gz",modulename);
 	/* First, try the current kernel */
-	snprintf(path,512,"/lib/modules/%s/kernel",utsbuf.release);
+	snprintf(path,512,"/lib/modules/%s",utsbuf.release);
 	/* Do not set the third argument of this function to < 6. Blarg. */
-	if (ftw(path,isModule,5) == 1) {
+	if (ftw(path,isModule,15) == 1) {
 		return 1;
 	}
 	/* If they're running a -BOOT kernel, try the original. */
@@ -877,19 +878,22 @@ int isAvailable(char *modulename)
 		len = strstr(utsbuf.release,"BOOT")-utsbuf.release;
 		strncpy(kernelver,utsbuf.release,len);
 		kernelver[len]='\0';
-		snprintf(path,512,"/lib/modules/%s/kernel",kernelver);
+		snprintf(path,512,"/lib/modules/%s",kernelver);
 		if (ftw(path,isModule,15) == 1) {
 			return 1;
 		}
-		snprintf(path,512,"/lib/modules/%ssmp/kernel",kernelver);
+		snprintf(path,512,"/lib/modules/%ssmp",kernelver);
 		if (ftw(path,isModule,15) == 1) {
 			return 1;
 		}
-		snprintf(path,512,"/lib/modules/%senterprise/kernel",kernelver);
+		snprintf(path,512,"/lib/modules/%sbigmem",kernelver);
+		if (ftw(path,isModule,15) == 1) {
+			return 1;
+		}
+		snprintf(path,512,"/lib/modules/%ssummit",kernelver);
 		if (ftw(path,isModule,15) == 1) {
 			return 1;
 		}
-		
 	}
 	/* Finally, try non-version specific directories. */
 	for (x = 0; searchdir[x]; x++) {
@@ -1677,7 +1681,7 @@ int main(int argc, char **argv)
     if (!quiet) {
 	rc = newtWinChoice(_("Introduction"), _("Ok"), _("Cancel"),
 			   _("sndconfig is a configuration tool for "
-			     "sound cards.\n\n%s%s\n\n"
+			     "legacy sound cards.\n\n%s%s\n\n"
 			     "Report bugs at http://bugzilla.redhat.com/bugzilla/")
 			   ,
 			   (noprobe) ?
